This package is an interface to the Arecibo application from ClearWind. It 
provides an interface for Plone to report its errors. 

This is the version that is updated for use with Plone 4 and has not been 
tested with previous versions but is likely to work with Plone 3 as well. It 
also adds generic setup support and support for complete configuration from 
the control panel.


For more information see: http://areciboapp.com and specifically 
http://www.areciboapp.com/docs/plone/   


  
